@@ -1,6 +1,6 @@
 package Courriel::Helpers;
 BEGIN {
-  $Courriel::Helpers::VERSION = '0.01';
+  $Courriel::Helpers::VERSION = '0.02';
 }
 
 use strict;
@@ -8,7 +8,12 @@ use warnings;
 
 use Exporter qw( import );
 
-our @EXPORT_OK = qw( fold_header parse_header_with_attributes );
+our @EXPORT_OK = qw(
+    fold_header
+    parse_header_with_attributes
+    quote_and_escape_attribute_value
+    unique_boundary
+);
 
 our $CRLF = "\x0d\x0a";
 
@@ -35,6 +40,16 @@ sub fold_header {
     return $folded;
 }
 
+sub quote_and_escape_attribute_value {
+    my $val = shift;
+
+    return $val unless $val =~ /[^a-zA-Z0-9\-]/;
+
+    $val =~ s/(\\|")/\\$1/g;
+
+    return qq{"$val"};
+}
+
 sub parse_header_with_attributes {
     my $text = shift;
 
@@ -69,6 +84,7 @@ sub _parse_attributes {
         }
         my $attribute = lc $1;
         my $value     = _extract_ct_attribute_value();
+        $value =~ s/\G(.*?)\\(.)/$1$2/g;
         $attribs->{$attribute} = $value;
     }
     return $attribs;
@@ -93,4 +109,8 @@ sub _extract_ct_attribute_value {    # EXPECTS AND MODIFIES $_
     return $value;
 }
 
+sub unique_boundary {
+    return Email::MessageID->new()->user();
+}
+
 1;
